commonactions

package
v2.8.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 15, 2025 License: BSD-3-Clause Imports: 4 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Panic

func Panic(e error) panicT

func SetActor

func SetActor(nextActor types.Actor) types.Action

SetActor sets the Actor (of the further actions).

func SetActorFunc

func SetActorFunc(nextActorFunc func(state *types.State) types.Actor) types.Action

SetActorFunc sets the Actor (of the further actions) given a function, which returns an actor expected for a specific State.

func SetFlow

func SetFlow(flow types.Flow) types.Action

SetFlow sets the Flow.

func SetFlowFunc

func SetFlowFunc(flowFunc func(state *types.State) types.Flow) types.Action

SetFlowFunc sets the Flow given a function, which returns a Flow expected for a specific State.

Types

type SetFlowStruct

type SetFlowStruct struct {
	NextFlow types.Flow
}

func (*SetFlowStruct) Apply

func (action *SetFlowStruct) Apply(_ context.Context, state *types.State) error

Apply implements types.Action.

func (*SetFlowStruct) String

func (action *SetFlowStruct) String() string

Jump to