inteldata

package
v2.8.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 15, 2025 License: BSD-3-Clause Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ACMDate

type ACMDate struct{}

ACMDate implements DataSource by referencing to the ACM date value.

func (ACMDate) Data

func (ACMDate) Data(ctx context.Context, state *types.State) (*types.Data, error)

Data implements types.DataSource.

func (ACMDate) String

func (ACMDate) String() string

String implements fmt.Stringer.

type FITAll

type FITAll fit.EntryType

FITAll implements DataSource by referencing to the data defined by the all FIT entries of the specified type.

func (FITAll) Data

func (d FITAll) Data(_ context.Context, state *types.State) (*types.Data, error)

Data implements types.DataSource.

func (FITAll) String

func (d FITAll) String() string

String implements fmt.Stringer.

type FITFirst

type FITFirst fit.EntryType

FITFirst implements DataSource by referencing to the data defined by the first FIT entry of the specified type.

func (FITFirst) Data

func (d FITFirst) Data(_ context.Context, state *types.State) (*types.Data, error)

Data implements types.DataSource.

func (FITFirst) String

func (d FITFirst) String() string

String implements fmt.Stringer.

type IBB

type IBB struct{}

IBB implements types.DataSource by referencing to the initial boot block.

func (IBB) Data

func (IBB) Data(ctx context.Context, s *types.State) (*types.Data, error)

Data implements types.DataSource.

func (IBB) String

func (IBB) String() string

Jump to