Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LogInfoProvider ¶
LogInfoProvider provides additional information used for tpm.CommandLog.
func NewLogInfoProvider ¶
func NewLogInfoProvider(s *types.State) *LogInfoProvider
NewLogInfoProvider returns a new instance of LogInfoProvider.
func (*LogInfoProvider) CauseAction ¶
func (p *LogInfoProvider) CauseAction() types.Action
Action returns the Action, which is the reason, why the tpm.Command was executed.
func (*LogInfoProvider) CauseCoordinates ¶
func (p *LogInfoProvider) CauseCoordinates() tpm.CauseCoordinates
CauseCoordinates returns the coordinates of the Action, which is the reason, why the tpm.Command was executed.
type TPMEvent ¶
type TPMEvent struct {
DataSource types.DataSource
PCRIndex pcr.ID
Type tpmeventlog.EventType
EventData []byte
}
TPMEvent is a representation of `TPM2_PCR_Event`.
func NewTPMEvent ¶
func NewTPMEvent( pcrIndex pcr.ID, dataSource types.DataSource, evType tpmeventlog.EventType, eventData []byte, ) *TPMEvent
NewTPMEvent returns a new instance of TPMEvent
type TPMEventLogAdd ¶
type TPMEventLogAdd struct {
PCRIndex pcr.ID
Algo tpm.Algorithm
Digest tpm.Digest
Type tpmeventlog.EventType
EventData []byte
}
TPMEvent is a representation of `TPM2_PCR_Event`.
func NewTPMEventLogAdd ¶
func NewTPMEventLogAdd( pcrIndex pcr.ID, algo tpm.Algorithm, digest []byte, evType tpmeventlog.EventType, eventData []byte, ) *TPMEventLogAdd
NewTPMEvent returns a new instance of TPMEvent
func (TPMEventLogAdd) String ¶
func (ev TPMEventLogAdd) String() string
String implements fmt.Stringer.
type TPMExtend ¶
TPMExtend is a representation of `TPM2_PCR_Extend`.
func NewTPMExtend ¶
func NewTPMExtend( pcrIndex pcr.ID, dataSource types.DataSource, hashAlgo tpm2.Algorithm, ) *TPMExtend
NewTPMExtend returns a new instance of TPMEvent.